<?php
declare(strict_types=1);

namespace FiloBlu\FailedPaymentEmailNotification\Observer;

use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;
use Magento\Sales\Api\PaymentFailuresInterface;
use Psr\Log\LoggerInterface;

class SendPaymentFailureEmailObserver implements ObserverInterface
{
    /**
     * @var LoggerInterface
     */
    private $logger;

    /**
     * @var PaymentFailuresInterface
     */
    private $paymentFailures;

    private $isEmailSent = false;

    public function __construct(
        LoggerInterface          $logger,
        PaymentFailuresInterface $paymentFailures
    )
    {
        $this->logger = $logger;
        $this->paymentFailures = $paymentFailures;
    }

    public function execute(Observer $observer)
    {
        try {
            if($this->isEmailSent) {
                return;
            }

            $quoteId = (int)$observer->getEvent()->getQuoteId();
            $message = $observer->getEvent()->getMessage();
            $this->paymentFailures->handle($quoteId, $message);
            $this->isEmailSent = true;
        } catch (\Exception $e) {
            $this->logger->error('Payment failure email - ' . $e->getMessage());
        }
    }
}
